docs.rs failed to build nostr-sqlite-0.45.0-alpha.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
nostr-sqlite-0.35.0
Nostr SQLite database backend
SQLite storage backend for nostr apps.
Crate Feature Flags
The following crate feature flags are available:
| Feature | Default | Description |
|---|---|---|
bundled |
Yes | Uses bundled SQLite |
Supported NIPs
| Supported | NIP |
|---|---|
| ❌ | 40 - Expiration Timestamp |
| ✅ | 50 - Search Capability |
| ✅* | 62 - Request to Vanish |
*: ALL_RELAYS only
Example for wasm32-unknown-unknown
Add sqlite-wasm-rs and sqlite-wasm-vfs to your Cargo.toml.
use *;
use WasmOsCallback;
use ;
use ;
const SQLITE_DB_PATH: &str = "my-db-name.sqlite3";
const SQLITE_OPFS_VFS: &str = "opfs-sahpool";
const SQLITE_IDB_VFS: &str = "relaxed-idb";
async
async
async
State
This library is in an ALPHA state, things that are implemented generally work but the API will change in breaking ways.
Donations
rust-nostr is free and open-source. This means we do not earn any revenue by selling it. Instead, we rely on your financial support. If you actively use any of the rust-nostr libs/software/services, then please donate.
License
This project is distributed under the MIT software license - see the LICENSE file for details